@@ -24,6 +24,7 @@
 #include "debug.h"
 #include "marshal.h"
 #include "vtebg.h"
+#include "vte-gtk-compat.h"
 
 #ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
@@ -128,7 +129,7 @@ vte_bg_root_surface(VteBg *bg)
 	g_free(pixmaps);
  out:
 	_vte_bg_display_sync(bg);
-	gdk_error_trap_pop();
+	gdk_error_trap_pop_ignored ();
 
 	return surface;
 }
@@ -240,7 +241,11 @@ vte_bg_get_for_screen(GdkScreen *screen)
 		window = gdk_screen_get_root_window(screen);
                 pvt->native.window = window;
                 pvt->native.native_window = gdk_x11_drawable_get_xid(window);
+#if GTK_CHECK_VERSION (2, 90, 8)
+                pvt->native.display = gdk_window_get_display(window);
+#else
                 pvt->native.display = gdk_drawable_get_display(GDK_DRAWABLE(window));
+#endif
                 pvt->native.native_atom = gdk_x11_get_xatom_by_name_for_display(pvt->native.display, "_XROOTPMAP_ID");
                 pvt->native.atom = gdk_x11_xatom_to_atom_for_display(pvt->native.display, pvt->native.native_atom);
 		pvt->root_surface = vte_bg_root_surface(bg);
